<?php
class OptionsPage
{
    /**
     * Holds the values to be used in the fields callbacks
     */
    private $options;

    /**
     * Start up
     */
    public function __construct()
    {
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
        add_action( 'admin_init', array( $this, 'page_init' ) );
        // Tracks new sections for whitelist_custom_options_page()
        $this->page_sections = array();
        // Must run after wp's `option_update_filter()`, so priority > 10
        add_action( 'whitelist_options', array( $this, 'whitelist_custom_options_page' ),11 );
    }

    // White-lists options on custom pages.
    // Workaround for second issue: http://j.mp/Pk3UCF
    public function whitelist_custom_options_page( $whitelist_options ){
        // Custom options are mapped by section id; Re-map by page slug.
        foreach($this->page_sections as $page => $sections ){
            $whitelist_options[$page] = array();
            foreach( $sections as $section )
                if( !empty( $whitelist_options[$section] ) )
                    foreach( $whitelist_options[$section] as $option )
                        $whitelist_options[$page][] = $option;
        }
        return $whitelist_options;
    }

    // Wrapper for wp's `add_settings_section()` that tracks custom sections
    private function add_settings_section( $id, $title, $cb, $page ){
        add_settings_section( $id, $title, $cb, $page );
        if( $id != $page ){
            if( !isset($this->page_sections[$page]))
                $this->page_sections[$page] = array();
            $this->page_sections[$page][$id] = $id;
        }
    }

    /**
     * Add options page
     */
    public function add_plugin_page()
    {
        // This page will be under "Settings"
        add_options_page(
            'Settings Admin',
            'Catermonkey settings',
            'manage_options',
            'Catermonkey-setting-admin',
            array( $this, 'create_admin_page' )
        );
    }

    /**
     * Options page callback
     */
    public function create_admin_page()
    {
        // Set class property
        $this->options = get_option( 'Catermonkey_settings' );
        ?>
        <div class="wrap">
            <h1>Catermonkey settings</h1>
            <form method="post" action="options.php">
            <?php
                // This prints out all hidden setting fields
                settings_fields( 'Catermonkey_settings' );
                do_settings_sections( 'Catermonkey-setting-admin' );
            ?>
            <?php submit_button(); ?>
            </form>

        </div>
        <?php
    }

    /**
     * Register and add settings
     */
    public function page_init()
    {
        register_setting(
            'Catermonkey_settings', // Option group
            'Catermonkey_settings', // Option name
            array( $this, 'sanitize' ) // Sanitize
        );

        $this->add_settings_section(
            'section1', // ID
            'Vul de Catermonkey API key in, deze is <a target="_blank" href="https://catermonkey.nl/app#/webshop">hier</a> te vinden', // Title
            array( $this, 'print_section_info' ), // Callback
            'Catermonkey-setting-admin' // Page
        );

        add_settings_field(
            'api_key', // ID
            'API-Key',
            array( $this, 'api_key_callback' ), // Callback
            'Catermonkey-setting-admin', // Page
            'section1' // Section
        );

    }

    /**
     * Sanitize each setting field as needed
     *
     * @param array $input Contains all settings fields as array keys
     */
    public function sanitize( $input )
    {
        $new_input = array();

        if( isset( $input['api_key'] ) )
            $new_input['api_key'] = sanitize_text_field( $input['api_key'] );

        return $new_input;
    }

    /**
     * Print the Section text
     */
    public function print_section_info()
    {
        print '';
    }

    /**
     * Get the settings option array and print one of its values
     */
    public function api_key_callback()
    {
        printf(
            '<input type="text" id="api_key" name="Catermonkey_settings[api_key]" value="%s" />',
            isset( $this->options['api_key'] ) ? esc_attr( $this->options['api_key']) : ''
        );
    }
}

if( is_admin() )
    $Catermonkey_settings_page = new OptionsPage();
