<?php
/**
 * Plugin Name: Catermonkey Woocommerce Integration
 * Plugin URI:  https://static.catermonkey.com/catermonkey-woocommerce.html
 * Description: Orders made in the woocommerce site are forwarded to your Catermonkey account.
 * Version:     0.0.4
 * License:     GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 * Author:      Marten Sytema
 * Developer:   Marten Sytema
 * Developer URI: https://catermonkey.com/about-us
 * Author URI:  https://catermonkey.com
 */
defined( 'ABSPATH' ) or die( 'no direct access' );

define('BACKEND_URL', 'https://app.catermonkey.com/');
//define('BACKEND_URL', ' http://cs2.local:3447');

include_once('OptionsPage.php');

//A WordPress installation can be configured so that the standard Plugin directory is changed from wp-content/plugins/,
//so you must use plugin_dir_path() and plugins_url() for absolute paths and URLs within your PHP code. For more details see Determining Plugin and Content Directories.

/**
 * Check if WooCommerce is active
 **/
add_action( 'woocommerce_email_before_order_table',  'handle_order_added', 10, 4);

if (!function_exists('write_log')) {

    function write_log($log) {
        if (true === WP_DEBUG) {
            if (is_array($log) || is_object($log)) {
                error_log(print_r($log, true));
            } else {
                error_log($log);
            }
        }
    }
}

function send_diagnostics($e){
    $str = $e->getTraceAsString();
    $errMsg = $e->getMessage();
    $msg =  "Something went wrong with the plugin, see diagnostics below\n\n". $errMsg ."\n\n". $str;
    $sub = 'Error in Catermonkey Woocommerce Plugin';
    wp_mail("marten@catermonkey.com", $sub, $msg);
}


function log_message($msg){
    write_log($msg);
    date_default_timezone_set('Europe/Amsterdam');
    file_put_contents(__DIR__.'/logs/order.log',date("Y-m-d H:i:s").': '.$msg."\n",FILE_APPEND);
}

function send_order_to_catermonkey($token, $order, $order_data, $items, $user) {
    $params = array('token' => $token,
                    'order' => $order,
                    'order_data' => $order_data,
                    'items' => $items,
                    'user' => $user);

    $params_string = json_encode($params);

    log_message("Sending: \n\n" . $params_string);
    log_message("PHP array format:");
    log_message(print_r($params, true));
    $url = BACKEND_URL . "/api/webshops/woocommerce-order";
    $defaults = array(
        CURLOPT_URL => $url,
        CURLOPT_CUSTOMREQUEST => "POST",
        CURLOPT_POSTFIELDS => $params_string,
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_HTTPHEADER => array('Content-Type: application/json',
                                    'Content-Length: '.strlen($params_string)));

    $ch = curl_init();
    curl_setopt_array($ch, $defaults);
    if( !$result = curl_exec($ch)) {
        throw new Exception ('Error in catermonkey wordpress plugin: '. curl_error($ch));
    }
    else {
        log_message($result);
    }
}

function handle_order_added($order, $sent_to_admin, $plain_text, $email ) {
    log_message ("handle order added: ".$email->id);
    try {
        if('new_order' == $email->id || "customer_processing_order" == $email->id ){
            $options  = get_option('Catermonkey_settings');
            write_log($options);
            $token = $options['api_key'];
            $order_data = $order->get_data();
            $items = array();
            foreach($order->get_items() as $item_key => $item) {
                $arr = (array) $item->get_data();
                $items[] = $arr;
            }
            foreach($order->get_items('shipping') as $item_key => $item) {
               $arr = (array) $item->get_data();
               $items[] = $arr;
            }
            foreach($order->get_items('fee') as $item_key => $item) {
                $arr = (array) $item->get_data();
                $items[] = $arr;
            }
            $user = $order->get_user();
            send_order_to_catermonkey($token, $order, $order_data, $items, $user);
        }
    } catch (Exception $e) {
        log_message($e->getMessage() . "\n\n" .$e->getTraceAsString());
        send_diagnostics($e);
    }
}
